# allprs

## Installation

```bash
# Using uv (will automatically install Python if necessary):
uv tool install allprs
# Using pipx:
pipx install allprs
# Using pip:
pip install allprs
```

## Python version support

This project will only ever support the latest released minor version of python, but will most likely work on older
versions as well. Change `requires-python` manually in `pyproject.toml` if necessary.
